@@ -1,8 +1,10 @@
+#' @export
 ardlDlm.default <-
-  function( formula = NULL , data = NULL , x = NULL, y = NULL , p = 1 , q = 1 , remove.p = NULL , remove.q = NULL , show.summary = TRUE){
+  function( formula = NULL , data = NULL , x = NULL, y = NULL , p = 1 , q = 1 , remove = NULL ){
     
     options(warn=-1)
-    
+    remove.p = remove$p
+    remove.q = remove$q
     q = round(q)
     if (q < 0){
       stop("Lag order q must be a positive integer!")
@@ -17,7 +19,7 @@ ardlDlm.default <-
         stop("Data series x and y both must be in a vector format!")
       }
       if (is.null(remove.p) == FALSE){
-        if (is.matrix(remove.p) == TRUE){
+        if (is.list(remove.p) == TRUE){
           stop("You must enter a vector or scalar to remove autoregressive parameters since you have only one independent series!")
         }
         if (length(remove.p) > p){
@@ -33,7 +35,7 @@ ardlDlm.default <-
         }
       }
       res = ardlDlm.main( x = x , y = y , p = p , q = q , 
-                          remove.p = remove.p , remove.q = remove.q , show.summary = show.summary , type = 1)
+                          remove = remove , type = 1)
       
     } else if ((is.null(formula) == FALSE) & (is.null(data) == FALSE)){
       if (is.formula(formula)== FALSE){
@@ -44,10 +46,10 @@ ardlDlm.default <-
       }
       
       if (is.null(remove.p) == FALSE){
-        if (is.matrix(remove.p) == FALSE){
-          stop("You must enter a matrix to remove autoregressive parameters!")
+        if (is.list(remove.p) == FALSE){
+          stop("You must enter a list to remove autoregressive parameters!")
         }
-        if (ncol(remove.p) > p){
+        if (length(remove.p) > p){
           stop("The number of autoregressive lags you want to remove is greater than the lag length!")
         }
       }
@@ -61,7 +63,7 @@ ardlDlm.default <-
       }
       
       res = ardlDlm.main( formula = formula , data = data , p = p , q = q , 
-                          remove.p = remove.p , remove.q = remove.q , show.summary = show.summary , type = 2)
+                          remove = remove , type = 2)
       
     } else if ((is.null(formula) == TRUE) & (is.null(data) == FALSE)){
       if ((is.vector(x)== FALSE) | (is.vector(y)== FALSE)){
