@@ -3,6 +3,9 @@ ardlDlmForecast.main = function(model , x , h = 1 , type , epsilon = NULL){
   if (is.null(epsilon) == TRUE){
     epsilon = array(0, h)
   }
+  vars = get.vars(model$formula)
+  indeps = vars[2:length(vars)] # get the names of independents variables
+  
   coefs = unlist(model$model$coefficients)
   design = unlist(model$model$model[nrow(model$model$model) , ]) # Get the last line of the design matrix
   p = model$order[1]
@@ -49,7 +52,7 @@ ardlDlmForecast.main = function(model , x , h = 1 , type , epsilon = NULL){
     k = nrow(x) # number of indep series
     y.obs = forecasts[1:q]
     x.obs = array(NA, dim = c(k , (p+1)))
-    full.model = ardlDlm(formula = model$formula , data = data.frame(model$data) , p = p , q = q , show.summary = FALSE)
+    full.model = ardlDlm(formula = model$formula , data = data.frame(model$data) , p = p , q = q )
     design = unlist(full.model$model$model[nrow(model$model$model) , ]) 
     designM = matrix(design[2:(length(design)-q)], nrow = k , ncol = (p+1) , byrow = TRUE)
     for ( j in 1:k){
@@ -57,11 +60,13 @@ ardlDlmForecast.main = function(model , x , h = 1 , type , epsilon = NULL){
       x.obs[j, ] = guyrot(x.obs[j, ],1)
       x.obs[j , 1] = x[j , 1] 
     }
-    removed.p = model$removed.p
-    removed.q = model$removed.q
+    removed.p = model$removed[["p"]]
+    removed.q = model$removed[["q"]]
     x.obsO = x.obs
     for ( j in 1:k){
-      x.obs[j , (removed.p[j , which(is.na(removed.p[ j , ]) == FALSE) ] + 1) ] = NA 
+      if ( is.null(removed.p[[indeps[j]]]) == FALSE){
+        x.obs[j , (removed.p[[indeps[j]]][which(is.na(removed.p[[indeps[j]]]) == FALSE) ] + 1) ] = NA 
+      }
     }
     seq.q = 1:q 
     seq.q = seq.q[ ! seq.q %in% removed.q]
@@ -75,7 +80,9 @@ ardlDlmForecast.main = function(model , x , h = 1 , type , epsilon = NULL){
           x.obs[j , 1] = x[j , (i - q + 1)]
         }
         x.obsO = x.obs
-        x.obs[j , (removed.p[j , which(is.na(removed.p[ j , ]) == FALSE) ] + 1) ] = NA
+        if ( is.null(removed.p[[indeps[j]]]) == FALSE){
+          x.obs[j , (removed.p[[indeps[j]]][which(is.na(removed.p[[indeps[j]]]) == FALSE) ] + 1) ] = NA
+        }
       }
       y.obs = forecasts[(i - q + 1):i]
     }
